@@ -10,8 +10,8 @@ use chrono::{Datelike, TimeZone, Timelike};
 
 use crate::writer::Writer;
 use crate::{
-    parse, parse_single, BitString, ObjectIdentifier, ParseError, ParseErrorKind, ParseLocation,
-    ParseResult, Parser,
+    parse, parse_single, BitString, ObjectIdentifier, OwnedBitString, ParseError, ParseErrorKind,
+    ParseLocation, ParseResult, Parser,
 };
 
 pub(crate) const CONTEXT_SPECIFIC: u8 = 0x80;
@@ -524,6 +524,12 @@ impl<'a> SimpleAsn1Writable<'a> for BitString<'a> {
         dest.extend_from_slice(self.as_bytes());
     }
 }
+impl<'a> SimpleAsn1Writable<'a> for OwnedBitString {
+    const TAG: u8 = 0x03;
+    fn write_data(&self, dest: &mut Vec<u8>) {
+        self.as_bitstring().write_data(dest);
+    }
+}
 
 /// Used for parsing and writing ASN.1 `UTC TIME` values. Wraps a
 /// `chrono::DateTime<Utc>`.
@@ -938,6 +944,7 @@ impl<'a, T: Asn1Readable<'a> + Asn1Writable<'a>> SimpleAsn1Writable<'a> for Sequ
 }
 
 /// Writes a `SEQUENCE OF` ASN.1 structure from a slice of `T`.
+#[derive(Hash, PartialEq)]
 pub struct SequenceOfWriter<'a, T: Asn1Writable<'a>, V: Borrow<[T]> = &'a [T]> {
     vals: V,
     _phantom: PhantomData<&'a T>,
@@ -1072,26 +1079,32 @@ impl<'a, T: Asn1Readable<'a> + Asn1Writable<'a>> SimpleAsn1Writable<'a> for SetO
     }
 }
 
-/// Writes an ASN.1 `SET OF` whose contents is a slice of `T`. This type is
-/// responsible for ensure the values are properly ordered when written as DER.
-pub struct SetOfWriter<'a, T: Asn1Writable<'a>> {
-    vals: &'a [T],
+/// Writes an ASN.1 `SET OF` whose contents is a slice of `T`. This type handles
+/// ensuring that the values are properly ordered when written as DER.
+#[derive(Hash, PartialEq)]
+pub struct SetOfWriter<'a, T: Asn1Writable<'a>, V: Borrow<[T]> = &'a [T]> {
+    vals: V,
+    _phantom: PhantomData<&'a T>,
 }
 
-impl<'a, T: Asn1Writable<'a>> SetOfWriter<'a, T> {
-    pub fn new(vals: &'a [T]) -> Self {
-        SetOfWriter { vals }
+impl<'a, T: Asn1Writable<'a>, V: Borrow<[T]>> SetOfWriter<'a, T, V> {
+    pub fn new(vals: V) -> Self {
+        SetOfWriter {
+            vals,
+            _phantom: PhantomData,
+        }
     }
 }
 
-impl<'a, T: Asn1Writable<'a>> SimpleAsn1Writable<'a> for SetOfWriter<'a, T> {
+impl<'a, T: Asn1Writable<'a>, V: Borrow<[T]>> SimpleAsn1Writable<'a> for SetOfWriter<'a, T, V> {
     const TAG: u8 = 0x11 | CONSTRUCTED;
     fn write_data(&self, dest: &mut Vec<u8>) {
-        if self.vals.is_empty() {
+        let vals = self.vals.borrow();
+        if vals.is_empty() {
             return;
-        } else if self.vals.len() == 1 {
+        } else if vals.len() == 1 {
             let mut w = Writer::new(dest);
-            w.write_element(&self.vals[0]);
+            w.write_element(&vals[0]);
             return;
         }
 
@@ -1102,7 +1115,7 @@ impl<'a, T: Asn1Writable<'a>> SimpleAsn1Writable<'a> for SetOfWriter<'a, T> {
         let mut spans = vec![];
 
         let mut pos = 0;
-        for el in self.vals {
+        for el in vals {
             w.write_element(el);
             let l = w.data.len();
             spans.push(pos..l);
