@@ -38,6 +38,13 @@ impl Writer<'_> {
         val.write(self);
     }
 
+    /// This is an alias for `write_element::<Explicit<T, tag>>`` for use when
+    /// MSRV is <1.51.
+    pub fn write_explicit_element<'a, T: Asn1Writable<'a>>(&mut self, val: &T, tag: u8) {
+        let tag = crate::explicit_tag(tag);
+        self.write_tlv(tag, |dest| Writer::new(dest).write_element(val));
+    }
+
     /// This is an alias for `write_element::<Option<Explicit<T, tag>>>` for
     /// use when MSRV is <1.51.
     pub fn write_optional_explicit_element<'a, T: Asn1Writable<'a>>(
@@ -71,8 +78,11 @@ impl Writer<'_> {
         }
     }
 
+    /// Writes a TLV with the specified tag where the value is any bytes
+    /// written to the `Vec` in the callback. The length portion of the
+    /// TLV is automatically computed.
     #[inline]
-    pub(crate) fn write_tlv<F: FnOnce(&mut Vec<u8>)>(&mut self, tag: u8, body: F) {
+    pub fn write_tlv<F: FnOnce(&mut Vec<u8>)>(&mut self, tag: u8, body: F) {
         self.data.push(tag);
         // Push a 0-byte placeholder for the length. Needing only a single byte
         // for the element is probably the most common case.
@@ -123,8 +133,9 @@ mod tests {
     use crate::types::Asn1Writable;
     use crate::{
         parse_single, BigUint, BitString, Choice1, Choice2, Choice3, Enumerated, GeneralizedTime,
-        IA5String, ObjectIdentifier, PrintableString, Sequence, SequenceOf, SequenceOfWriter,
-        SequenceWriter, SetOf, SetOfWriter, Tlv, UtcTime, Utf8String, VisibleString,
+        IA5String, ObjectIdentifier, OwnedBitString, PrintableString, Sequence, SequenceOf,
+        SequenceOfWriter, SequenceWriter, SetOf, SetOfWriter, Tlv, UtcTime, Utf8String,
+        VisibleString,
     };
     #[cfg(feature = "const-generics")]
     use crate::{Explicit, Implicit};
@@ -293,6 +304,18 @@ mod tests {
                 b"\x03\x03\x04\x81\xf0",
             ),
         ]);
+
+        assert_writes::<OwnedBitString>(&[
+            (OwnedBitString::new(vec![], 0).unwrap(), b"\x03\x01\x00"),
+            (
+                OwnedBitString::new(vec![0x80], 7).unwrap(),
+                b"\x03\x02\x07\x80",
+            ),
+            (
+                OwnedBitString::new(vec![0x81, 0xf0], 4).unwrap(),
+                b"\x03\x03\x04\x81\xf0",
+            ),
+        ]);
     }
 
     #[test]
@@ -400,7 +423,7 @@ mod tests {
 
     #[test]
     fn test_write_set_of() {
-        assert_writes(&[
+        assert_writes::<SetOfWriter<u8, &[u8]>>(&[
             (SetOfWriter::new(&[]), b"\x31\x00"),
             (SetOfWriter::new(&[1u8]), b"\x31\x03\x02\x01\x01"),
             (
@@ -412,6 +435,18 @@ mod tests {
                 b"\x31\x09\x02\x01\x01\x02\x01\x02\x02\x01\x03",
             ),
         ]);
+        assert_writes(&[
+            (SetOfWriter::new(vec![]), b"\x31\x00"),
+            (SetOfWriter::new(vec![1u8]), b"\x31\x03\x02\x01\x01"),
+            (
+                SetOfWriter::new(vec![1, 2, 3]),
+                b"\x31\x09\x02\x01\x01\x02\x01\x02\x02\x01\x03",
+            ),
+            (
+                SetOfWriter::new(vec![3, 2, 1]),
+                b"\x31\x09\x02\x01\x01\x02\x01\x02\x02\x01\x03",
+            ),
+        ]);
 
         assert_writes(&[(
             parse_single::<SetOf<u64>>(b"\x31\x06\x02\x01\x05\x02\x01\x07").unwrap(),
